@@ -138,13 +138,10 @@
 #' @examples
 #' data(Moore1998)
 #' m1 <- metabin(succ.e, nobs.e, succ.c, nobs.c,
-#'               data = Moore1998, sm = "OR", method = "Inverse")
+#'   data = Moore1998, sm = "OR", method = "Inverse")
 #' 
 #' print(limitmeta(m1), digits = 2)
 #' @export limitmeta
-#'
-#' @importFrom meta ci metagen
-#' @importFrom stats sd
 
 
 limitmeta <- function(x,
@@ -213,8 +210,16 @@ limitmeta <- function(x,
     ##
     ## Expectation (beta-0)
     ##
-    TE.adjust   <- as.vector(beta.r + tau * alpha.r)
-    seTE.adjust <- as.vector(1 / sd(sqrt(1 / seTE^2)) / sqrt(k - 1))
+    TE.adjust <- as.vector(beta.r + tau * alpha.r)
+    ##
+    var.beta <-
+      as.vector(1 / var(sqrt(w.random)) / (k - 1))
+    var.alpha <-
+      as.vector(mean(w.random) / var(sqrt(w.random)) / (k - 1))
+    cov.alpha.beta <-
+      as.vector(- mean(sqrt(w.random)) / var(sqrt(w.random)) / (k - 1))
+    ##
+    seTE.adjust <- sqrt(var.beta + tau^2 * var.alpha + 2 * tau * cov.alpha.beta)
   }
   else {
     if (method.adjust == "mulim") {
